package com.qihoo360.mobilesafe.reward.container

import android.content.Context
import android.util.AttributeSet
import android.view.View
import android.view.ViewGroup
import android.widget.LinearLayout
import com.qihoo360.apullsdk.apull.protocol.ApullReportManager
import com.qihoo360.apullsdk.apull.protocol.model.ApullTemplateBase
import com.qihoo360.apullsdk.apull.protocol.model.impl.TemplateApullApp
import com.qihoo360.apullsdk.apull.protocol.model.impl.TemplateApullMv
import com.qihoo360.apullsdk.apull.protocol.model.impl.TemplateGdt
import com.qihoo360.apullsdk.apull.view.ApullContainerBase
import com.qihoo360.apullsdk.utils.DensityUtil
import com.qihoo360.mobilesafe.extension.onClick
import com.qihoo360.mobilesafe.extension.setVisible
import com.qihoo360.mobilesafe.extension.tryCatch
import com.qihoo360.mobilesafe.reward.container.app.ContainerApullApp80
import com.qihoo360.mobilesafe.reward.container.gdt.ContainerGdt2105
import com.qihoo360.mobilesafe.reward.container.mv.ContainerApullMv531
import com.qihoo360.mobilesafe.support.log.Logger
import com.qihoo360.newssdk.protocol.model.TemplateApullProxy
import com.qihoo360.newssdk.protocol.model.TemplateBase
import java.util.ArrayList

private const val PV_CHECK_TIME = 1
private const val TAG = "RewardContainer"

class RewardContainer : ContainerBase {

    private var mLists= mutableListOf<Pair<ApullTemplateBase?,ApullContainerBase?>>()

    private var mListViews = mutableListOf<ApullContainerBase>()

    private var mTemplateLists = mutableListOf<ApullTemplateBase>()

    private var mLoopIndex: Int = 0

    private lateinit var mContentView: LinearLayout

    private var PAGE_COUNT = 3 //每页显示3个

    private var mIndexPage = 0  //页数索引

    private var mAllTemplateSize = 0  //总共的模版数

    private var mPageSize = 0  //总共页数

    constructor(context:Context):super(context)

    constructor(context: Context,attrs: AttributeSet):super(context,attrs)

    constructor(context: Context,lists : Collection<Pair<ApullTemplateBase?,ApullContainerBase?>>,pageCount :Int = 3):super(context){
        initView()
        mLists.addAll(lists)
        this.PAGE_COUNT = pageCount
        initUpdateView()

    }

    override fun initView() {
        mContentView = LinearLayout(mContext)
        mContentView.orientation = LinearLayout.HORIZONTAL
        addView(mContentView)
    }

    private fun initUpdateView() {
        if(mLists.isEmpty()){
            return
        }
        mLists.apply {
            tryCatch({
                Logger.d(TAG,"updatePageIndexView else exception")
                Logger.handleException(it)
                removeAllViews()
                setVisible(false)
                return
            }){
                val mParamSingle = LayoutParams(0,ViewGroup.LayoutParams.WRAP_CONTENT)
                mParamSingle.weight = 1.0f

                val iterator = iterator()
                while (iterator.hasNext()){
                    val templatePairs = iterator.next()
                    val template = templatePairs.first
                    val container  = templatePairs.second
                    template?.let {
                        container?.apply {
                            setVisible(false)
                            mListViews.add(this)
                            mTemplateLists.add(it)
                            mContentView.addView(this,mParamSingle)
                        }
                    }
                }
                if(mListViews.isNotEmpty() && mTemplateLists.isNotEmpty()) {
                    mAllTemplateSize = mListViews.size
                    Logger.d(TAG, "mAllTemplateSize = $mAllTemplateSize")

                    mIndexPage = 0
                    val sizeReminder = mAllTemplateSize % PAGE_COUNT
                    var sizePageReminder = 0

                    if (sizeReminder > 0) {
                        sizePageReminder = 1
                    }
                    mPageSize = mAllTemplateSize / PAGE_COUNT + sizePageReminder
                    Logger.d(TAG, "mPageSize = $mPageSize")

                    updatePageIndexView(mIndexPage)
                }
            }
        }

    }

    fun updatePageIndexView(){
         mIndexPage++
         if(mIndexPage >= mPageSize){
             mIndexPage = 0
         }
        updatePageIndexView(mIndexPage)
    }

    private fun updatePageIndexView(page:Int) {
        if (mListViews.size == 0 || mTemplateLists.size == 0 ) {
            mIndexPage = 0
            removeAllViews()
            setVisible(false)
            return
        }else {
             tryCatch({
                 Logger.d(TAG,"updatePageIndexView else exception")
                 Logger.handleException(it)
                 removeAllViews()
                 setVisible(false)
                 return
             }){
                 for (view in mListViews) {
                     (view as? View)?.setVisible(false)
                 }

                 var realPage = if (page >= mPageSize) {
                     page % mPageSize
                 } else {
                     page
                 }

                 var index = realPage * PAGE_COUNT

                 for (i in index until index + PAGE_COUNT) {
                     if (i >= mAllTemplateSize) {
                         break
                     }
                     mListViews[i].setVisible(true)
                 }
             }
        }

    }

    override fun handleLoop() {
        // 刚初始化时不进行上报
        mLoopIndex++
        if (mLoopIndex <= 1) {
            return
        }

        // pv
        if (mLoopIndex % PV_CHECK_TIME == 0) {
            reportPv()
        }
    }

    private fun reportPv() {
        if (mListViews.isEmpty())
            return

        val location = IntArray(2)
        tryCatch {
            getLocationOnScreen(location)
        }
        var mScreenHeight = DensityUtil.getScreenHeight(context)
        if (location[1] in 1..(mScreenHeight - 1)) {
            if(!mListViews.isEmpty() && !mTemplateLists.isEmpty()){

                val startIndex = PAGE_COUNT * mIndexPage
                var endIndex = startIndex + PAGE_COUNT - 1

                if(endIndex >= mTemplateLists.size){
                    endIndex = mTemplateLists.size - 1
                }
                if(startIndex <= endIndex) {
                    for (index in startIndex..endIndex step 1) {
                        val template = mTemplateLists[index]
                        if(!template.pv_reported){
                            ApullReportManager.reportApullPvAll(this@RewardContainer.mContext,template)
                        }
                    }
                }
            }
        }
    }

   private fun addTemplateAndView(context: Context?,template: ApullTemplateBase?,container:ApullContainerBase?){
        context?.apply {
            template?.let {
                if (container != null){
                  val pair = Pair(it, container)
                    mLists.add(pair)
                    mListViews.add(container)
                    mTemplateLists.add(template)
                }
            }
        }
    }

    fun getCount() :Int{
        return mListViews.size
    }

}