package com.qihoo360.mobilesafe.reward.data

import com.qihoo360.apullsdk.apull.ApullConst
import com.qihoo360.apullsdk.apull.protocol.model.ApullItemBase
import com.qihoo360.apullsdk.apull.protocol.model.ApullTemplateBase
import com.qihoo360.apullsdk.apull.protocol.model.impl.TemplateApullApp
import com.qihoo360.apullsdk.apull.protocol.model.impl.TemplateApullMv
import com.qihoo360.apullsdk.apull.protocol.model.impl.TemplateApullTouTiao
import com.qihoo360.apullsdk.apull.protocol.model.impl.TemplateGdt
import com.qihoo360.apullsdk.apull.protocol.model.impl.app.ApullAppItem
import com.qihoo360.apullsdk.apull.protocol.model.impl.gdt.ApullGdtItem
import com.qihoo360.apullsdk.apull.protocol.model.impl.mv.ApullMvItem
import com.qihoo360.apullsdk.apull.protocol.model.impl.toutiao.ApullTouTiaoItem
import org.json.JSONObject

/**
 * 暂时不支持多格
 */
class ApullItemWrapper {

    private var mApullTemplateBase: ApullTemplateBase? = null

    private var mProtocolType = 0

    var uniqueId = ""

    private var downloadId :String? = ""

    companion object {
        const val APP = 1 //APP协议
        const val MV = 2 //MAX协议
        const val GDT = 3 //广点通
        const val TOUTIAO = 4//头条


        fun convertJSON2Template(type:Int,json:JSONObject?):ApullTemplateBase?{
            var templateBase :ApullTemplateBase? = null
            if(type in ApullItemWrapper.APP..ApullItemWrapper.TOUTIAO){
                when(type){
                    ApullItemWrapper.APP ->{
                        templateBase =  TemplateApullApp.createFromJsonString(json?.toString())
                    }
                    ApullItemWrapper.MV ->{
                        templateBase = TemplateApullMv.createFromJsonString(json?.toString())
                    }
                    ApullItemWrapper.GDT ->{
                        templateBase = TemplateGdt.createFromJsonString(json?.toString())
                    }
                    ApullItemWrapper.TOUTIAO ->{
                        templateBase = TemplateApullTouTiao.createFromJsonString(json?.toString())
                    }
                }
            }

            return templateBase
        }
    }

    constructor(templateBase: ApullTemplateBase) {
        this.mApullTemplateBase = templateBase
        this.mProtocolType = when(templateBase){
            is TemplateApullApp -> APP
            is TemplateApullMv  -> MV
            is TemplateGdt -> GDT
            is TemplateApullTouTiao -> TOUTIAO
            else -> {
                -1
            }
        }
        init()
    }


    fun init() {
        getDefaultItem(true)
    }

    fun getTemplateType() = mApullTemplateBase?.type ?: 0

    fun getDefaultItem(init :Boolean): ApullItemBase? {
        mApullTemplateBase?.apply {
            if (mProtocolType == APP) {
                (this as? TemplateApullApp)?.defaultItem?.let {
                    if(init) {
                        uniqueId = it.unique_id ?: ""
                        downloadId = this.downloadid
                    }
                    return it
                }
            }

            if (mProtocolType == MV) {
                (this as? TemplateApullMv)?.defaultItem?.let {
                    if(init) {
                        uniqueId = it.unique_id ?: ""
                        downloadId = this.downloadid
                    }
                    return it
                }
            }

            if (mProtocolType == GDT) {
                (this as? TemplateGdt)?.defaultItem?.let {
                    if(init) {
                        uniqueId = it.unique_id?: ""
                        downloadId = this.downloadid
                    }
                    return it
                }
            }

            if(mProtocolType == TOUTIAO){
                (this as? TemplateApullTouTiao)?.defaultItem?.let {
                    if(init) {
                        uniqueId = it.unique_id?: ""
                        downloadId = this.downloadid
                    }
                    return it
                }
            }
        }
        return null
    }

    fun equalsUniqueId(mApullItemWrapper: ApullItemWrapper?): Boolean {
        mApullItemWrapper?.let {
            return it.uniqueId == uniqueId
        }
        return false
    }

    fun equalsDownloadId(downloadId: String?): Boolean {
        downloadId?.let {
            return it == this.downloadId
        }
        return false
    }

    fun getDownloadStatus(): Int {
        var status = ApullConst.STATUS_TYPE_DOWNLOAD
        val itemWrapper = getDefaultItem(false)

        if(mProtocolType == APP) {
           val item = itemWrapper as? ApullAppItem
            status = item?.status ?: ApullConst.STATUS_TYPE_DOWNLOAD
        }

        if(mProtocolType == MV) {
            val item = itemWrapper as? ApullMvItem
            status = item?.status ?: ApullConst.STATUS_TYPE_DOWNLOAD
        }

        if(mProtocolType == GDT) {
            val item = itemWrapper as? ApullGdtItem
            status = item?.status ?: ApullConst.STATUS_TYPE_DOWNLOAD
        }

        if(mProtocolType == TOUTIAO){
            val item = itemWrapper as? ApullTouTiaoItem
            status = item?.status ?: ApullConst.STATUS_TYPE_DOWNLOAD
        }
        return status
    }

    fun setDownloadStatus(status: Int) {

        val itemWrapper = getDefaultItem(false)

        if(mProtocolType == APP) {
            val item = itemWrapper as? ApullAppItem
            item?.status = status
        }

        if(mProtocolType == MV) {
            val item = itemWrapper as? ApullMvItem
            item?.status = status
        }

        if(mProtocolType == GDT) {
            val item = itemWrapper as? ApullGdtItem
            item?.status = status
        }

        if(mProtocolType == TOUTIAO){
            val item = itemWrapper as? ApullTouTiaoItem
            item?.status = status
        }
    }

    fun getDownloadProgress(): Int {
        var progress = 0

        val itemWrapper = getDefaultItem(false)

        if(mProtocolType == APP) {
            val item = itemWrapper as? ApullAppItem
            progress = item?.progress ?: 0
        }

        if(mProtocolType == MV) {
            val item = itemWrapper as? ApullMvItem
            progress = item?.progress ?: 0
        }

        if(mProtocolType == GDT) {
            val item = itemWrapper as? ApullGdtItem
            progress = item?.progress ?: 0
        }

        if(mProtocolType == TOUTIAO){
            val item = itemWrapper as? ApullTouTiaoItem
            progress = item?.progress ?: 0
        }
        return progress
    }

    fun setDownloadProgress(progress: Int){

        val itemWrapper = getDefaultItem(false)

        if(mProtocolType == APP) {
            val item = itemWrapper as? ApullAppItem
            item?.progress = progress
        }

        if(mProtocolType == MV) {
            val item = itemWrapper as? ApullMvItem
            item?.progress = progress
        }

        if(mProtocolType == GDT) {
            val item = itemWrapper as? ApullGdtItem
            item?.progress = progress
        }

        if(mProtocolType == TOUTIAO){
            val item = itemWrapper as? ApullTouTiaoItem
            item?.progress = progress
        }
    }

    fun getProtocolType(): Int {
        return mProtocolType
    }

    fun getDownloadId(): String? {
        return downloadId
    }

    fun getIconUrl(): String? {
        var url :String? = ""
        val itemWrapper = getDefaultItem(false)
        when (mProtocolType) {
            APP -> {
                val item =  (itemWrapper as? ApullAppItem)
                url = item?.image_url
            }
            MV -> {
                val item = (itemWrapper as? ApullMvItem)
                item?.let {
                    item.logo?.apply {
                        url = item.logo
                    }?:kotlin.run {
                        url = it.imageUrl
                    }
                }
            }
            GDT -> {
                val item = (itemWrapper as? ApullGdtItem)
                url = item?.img2_url
            }

            TOUTIAO -> {
                val item = (itemWrapper as? ApullTouTiaoItem)
                url = item?.icon
            }
            else->{

            }
        }
        return url
    }

    fun getAppName():String? {
        var appName :String? = ""
        val itemWrapper = getDefaultItem(false)
        when (mProtocolType) {
            APP -> {
                val item =  (itemWrapper as? ApullAppItem)
                appName = item?.app_name
            }
            MV -> {
                val item = (itemWrapper as? ApullMvItem)
                 appName = item?.app_name
            }
            GDT -> {
                val item = (itemWrapper as? ApullGdtItem)
                appName = item?.title
            }
            TOUTIAO ->{
                val item = (itemWrapper as? ApullTouTiaoItem)
                appName = item?.appNameOrTitle
            }
        }
        return appName
    }

    fun setDownloadFilePath(filePath: String?) {

        val itemWrapper = getDefaultItem(false)

        if(mProtocolType == APP) {
            val item = itemWrapper as? ApullAppItem
            item?.filePath = filePath
        }

        if(mProtocolType == MV) {
            val item = itemWrapper as? ApullMvItem
            item?.filePath = filePath
        }

        if(mProtocolType == GDT) {
            val item = itemWrapper as? ApullGdtItem
            item?.filePath = filePath
        }

        if(mProtocolType == TOUTIAO){
            val item = itemWrapper as? ApullTouTiaoItem
            item?.filePath =filePath
        }
    }

    fun setDownloadiType(iType: Int) {

        val itemWrapper = getDefaultItem(false)

        if(mProtocolType == APP) {
            val item = itemWrapper as? ApullAppItem
            item?.iType = iType
        }

        if(mProtocolType == MV) {
            val item = itemWrapper as? ApullMvItem
            item?.iType= iType
        }

        if(mProtocolType == GDT) {
           // val item = itemWrapper as? ApullGdtItem
        }

        if(mProtocolType == TOUTIAO){
            val item = itemWrapper as? ApullTouTiaoItem
            item?.iType = iType
        }
    }

    fun getRewardPackageName() :String?{

        var pkgName :String? = ""
        val itemWrapper = getDefaultItem(false)
        when (mProtocolType) {
            APP -> {
                val item =  (itemWrapper as? ApullAppItem)
                pkgName = item?.pkgname
            }
            MV -> {
                val item = (itemWrapper as? ApullMvItem)
                pkgName = item?.deeplink_pkgname
                if(pkgName.isNullOrEmpty()){
                    pkgName = item?.package_name
                }
            }
            GDT -> {
                val item = (itemWrapper as? ApullGdtItem)
                pkgName = item?.pkgname
            }
            TOUTIAO -> {
                val item = (itemWrapper as? ApullTouTiaoItem)
                pkgName = item?.package_name
            }

            else->{

            }
        }
        return pkgName
    }

    /**
     * MV协议打开类deepLink（条件：本地已经安装deepLink应用，
     *                         若本地未安装应用，则可以判断interaction_object.url当作form表单普通打开类，跳转到webView）
     */
    fun isOpenDeepLink() : Boolean{
        val apullItem = getDefaultItem(false)
        if(apullItem is ApullMvItem){
            return apullItem.interaction_type == 2
            && apullItem.interaction_object?.deeplink.isNullOrEmpty().not()
        }
        return false
    }


    /**
     * MV协议打开类（淘宝类，form表单类，h5广告聚合类
     */
    fun isOpenTypeH5() :Boolean{
        val apullItem = getDefaultItem(false)
        if(apullItem is ApullMvItem){
            return apullItem.interaction_type == 2
                   && apullItem.interaction_object?.url.isNullOrEmpty().not()
                   && apullItem.open_type == 1
        }
        return false
    }

    /**
     * MV协议普通下载类
     */
    fun isDownload() :Boolean{
        val apullItem = getDefaultItem(false)
        if(apullItem is ApullMvItem){
            return apullItem.interaction_type == 3
        }
        return false
    }

    /**
     * mv协议普通下载类，打开时可以用deepLink,如果已经安装,则直接打开rewardType = 3
     */
    fun isDownloadDeepLink() :Boolean{
        val apullItem = getDefaultItem(false)
        if(apullItem is ApullMvItem){
            return apullItem.interaction_type == 3
            && apullItem.interaction_object?.deeplink.isNullOrEmpty().not()
        }
        return false
    }

    fun getTemplate():ApullTemplateBase?{
        return mApullTemplateBase
    }

    fun getAppItemFormType() :Int{
        var mFormType = -1

        val itemWrapper = getDefaultItem(false)

        if(mProtocolType == APP) {
            val item = itemWrapper as? ApullAppItem
            mFormType = item?.form_type ?: -1
        }

        if(mProtocolType == MV) {
            val item = itemWrapper as? ApullMvItem
            mFormType = item?.interaction_type ?:-1
        }

        if(mProtocolType == GDT) {
            val item = itemWrapper as? ApullGdtItem
            mFormType = item?.interact_type ?:-1
        }

        if(mProtocolType == TOUTIAO){
            val item = itemWrapper as? ApullTouTiaoItem
            mFormType = item?.interaction_type?:-1
        }
        return mFormType
    }

    /**
     * APP协议整点红包模版打开类
     */
    fun isHourOpenType() :Boolean{
        return getProtocolType() == APP && getAppItemFormType() == 1
    }
}

