package com.qihoo360.mobilesafe.reward.ui

import android.annotation.SuppressLint
import android.app.Dialog
import android.content.Context
import android.graphics.Color
import android.text.TextUtils
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.BaseAdapter
import android.widget.TextView
import com.qihoo360.mobilesafe.extension.clickWithTrigger
import com.qihoo360.mobilesafe.reward.R
import com.qihoo360.mobilesafe.reward.data.RewardRecordManager
import com.qihoo360.mobilesafe.ui.common.dialog.CommonDialog
import java.text.SimpleDateFormat
import java.util.*


class RewardAdapter(private val mRewardRecordManager: RewardRecordManager?, private val mContext: Context,
                    dialog: CommonDialog, private val mList: List<RewardRecordManager.RewardRecord>?) : BaseAdapter() {

    private val mDialog: Dialog

    val formater = SimpleDateFormat("yyyy年MM月dd日 HH:mm:ss", Locale.ENGLISH)

    init {
        mDialog = dialog
    }

    override fun getCount(): Int {
        return mList?.size ?: 0
    }

    override fun getItem(position: Int): Any? {
        return if (mList == null) {
            null
        } else mList[position]
    }

    override fun getItemId(position: Int): Long {
        return position.toLong()
    }

    @SuppressLint("ViewHolder")
    override fun getView(position: Int, convertView: View?, parent: ViewGroup?): View {
        val view =  LayoutInflater.from(mContext).inflate(R.layout.reward_record_item, null)
        val array_title = view.findViewById(R.id.reward_record_item_title) as TextView
        val array_text = view.findViewById(R.id.reward_record_item_text) as TextView
        val array_button = view.findViewById(R.id.reward_record_item_button) as TextView
        val rewardRecord:RewardRecordManager.RewardRecord? = mList!![position]
        if (rewardRecord != null) {
            if (rewardRecord.commitResponse != null &&
                    rewardRecord.commitResponse.amount >= 0 &&
                    !TextUtils.isEmpty(rewardRecord.commitResponse.transId)) {
                array_title.text = mContext.getString(R.string.reward_record_amount,
                        rewardRecord.commitResponse.amount / 100.0)
                array_button.setBackgroundDrawable(null)
                array_button.setTextColor(Color.rgb(88, 88, 88))
                array_button.text = mContext.getString(R.string.reward_record_opened)
            } else if (rewardRecord.commitResponse != null &&
                    !TextUtils.isEmpty(rewardRecord.commitResponse.uniqueId) &&
                    TextUtils.isEmpty(rewardRecord.commitResponse.transId)) {
                array_title.text = mContext.getString(R.string.reward_record_unopen)
                array_button.setBackgroundDrawable(null)
                array_button.setTextColor(Color.rgb(88, 88, 88))
                array_button.text = mContext.getString(R.string.reward_record_timeout)
            } else if (rewardRecord.tryResponse != null) {
                array_title.text = mContext.getString(R.string.reward_record_unopen)
                array_button.setBackgroundResource(R.drawable.common_btn_1_normal)
                array_button.setTextColor(mContext.resources.getColor(R.color.common_font_color_7))
                array_button.text = mContext.getString(R.string.reward_record_open)
                array_button.clickWithTrigger {
                    if (mRewardRecordManager?.handleRecordOpen(rewardRecord) == true) {
                            mDialog.dismiss()
                    }
                }
            }

            array_text.text = formater.format(rewardRecord.timeStamp)
        }
        return view
    }
}
