package com.qihoo360.mobilesafe.reward.ui.page

import android.content.Intent
import android.os.Bundle
import android.view.View
import android.webkit.WebView
import android.webkit.WebViewClient
import com.qihoo.pdown.uitls.Base64
import com.qihoo360.apullsdk.utils.WebViewResourceHelper
import com.qihoo360.framework.base.IKillable
import com.qihoo360.mobilesafe.LocalBroadcastManagerC
import com.qihoo360.mobilesafe.authguide.service.AuthGuideServiceHelper
import com.qihoo360.mobilesafe.extension.toast
import com.qihoo360.mobilesafe.extension.tryCatch
import com.qihoo360.mobilesafe.reward.*
import com.qihoo360.mobilesafe.reward.data.*
import com.qihoo360.mobilesafe.reward.data.IntentConstant.Companion.EXTRA_JSON_INFO
import com.qihoo360.mobilesafe.reward.data.IntentConstant.Companion.EXTRA_KEY_REFER_PAGE_ID
import com.qihoo360.mobilesafe.reward.data.IntentConstant.Companion.EXTRA_KEY_REFER_SUB_PAGE_ID
import com.qihoo360.mobilesafe.reward.presenter.base.BaseMVPActivity
import com.qihoo360.mobilesafe.reward.presenter.RewardPresenter
import com.qihoo360.mobilesafe.reward.presenter.view.RewardView
import com.qihoo360.mobilesafe.reward.ui.page.dialog.*
import com.qihoo360.mobilesafe.support.log.Logger
import com.qihoo360.mobilesafe.ui.common.dialog.CommonLoadingCircleDialog
import com.qihoo360.mobilesafe.ui.common.other.CommonPopupWindow
import com.qihoo360.mobilesafe.ui.common.other.CommonWebChromeClientEx
import kotlinx.android.synthetic.main.page_raffle.*


open class RaffleBaseActivity :BaseMVPActivity<RewardPresenter>(),RewardView ,IKillable,View.OnClickListener{


    protected var mRewardDownloadDialog : RewardDownloadDialog? = null
    protected var mRewardResultDialog : RewardResultDialog? = null

    companion object {
        val DEBUG = Logger.bDebug()
        const val TAG =  "RaffleBaseActivity"
    }

    private lateinit var mLoadingDialog : CommonLoadingCircleDialog

    lateinit var mFromIntentData : FromIntentData

    protected  var mPopupWindow : CommonPopupWindow? = null

    override fun onCreate(savedInstanceState: Bundle?) {
        tryCatch({
            Logger.handleException(it)
            toast(getString(R.string.apull_webview_error))
            finish()
            return
        }){
            setUseStatusBarTranslucent(true)
            super.onCreate(savedInstanceState)
        }

        Logger.d(TAG, "RaffleBaseActivity onCreate")

        initData()
        initView()
        requestRewardAd()
    }


    open  fun initData() {
       intent?.apply {
           initIntentData()
       }
    }

    private fun initIntentData() {
        tryCatch({
            Logger.handleException(it)
            Logger.d(TAG, "initIntentData exception")
        }){
            val mReferScene = intent.getIntExtra(EXTRA_KEY_REFER_PAGE_ID, 0)
            val mReferSubScene = intent.getIntExtra(EXTRA_KEY_REFER_SUB_PAGE_ID, 0)
            val base64 = intent.getStringExtra(EXTRA_JSON_INFO)
            val rawStr =
                    if(base64.isNullOrEmpty().not()) {
                        String(Base64.decode(base64))
                    }
                    else {
                        null
                    }
            mFromIntentData = FromIntentData()
            mFromIntentData.mReferScene= mReferScene
            mFromIntentData.mReferSubScene = mReferSubScene
            mFromIntentData.applyData(rawStr)
            initDefaultData()
        }
    }

    open fun initDefaultData(){

    }

    override fun initPresenter() {
        tryCatch({
            Logger.d(TAG,"initPresenter exception")
            Logger.handleException(it)
        }){
            mPresenter = RewardPresenter()
            mPresenter.init(this)
            mPresenter.attachView(this)
        }

    }

    private fun initView() {
        mLoadingDialog = CommonLoadingCircleDialog(this,"努力加载中……")
        initWebView()
        initTitleView()
    }

    open fun initTitleView() {

    }

    open fun initWebView() {
        val ws = mWebView.settings
        ws.javaScriptEnabled = true
        ws.domStorageEnabled = true
        mWebView.setVerticalScrollbarOverlay(false)
        mWebView.setWebViewClient(object : WebViewClient() {
            override fun shouldOverrideUrlLoading(view: WebView?, url: String?): Boolean {
                return false
            }

            override fun onPageFinished(view: WebView?, url: String?) {
                this@RaffleBaseActivity.onPageFinished(view,url)
                super.onPageFinished(view, url)
            }
        })
        mWebView.setWebChromeClient(CommonWebChromeClientEx())

        if (mFromIntentData.mUrl.isEmpty().not()) {
            mWebView.loadUrl(mFromIntentData.mUrl)
        }

        tryCatch {
            WebViewResourceHelper.addChromeResourceIfNeeded(this)
        }
    }

    open fun onPageFinished(view: WebView?, url: String?) {

    }

    override fun onClick(v: View?) {
    }

    override fun isKillable(): Boolean {
        return false
    }

    open fun requestRewardAd() {
        showLoadingDialog()
    }

    override fun showLoadingDialog() {
      mLoadingDialog.show()
    }

    override fun hideLoadingDialog() {
       mLoadingDialog.dismiss()
    }

     override  fun onRewardResponse(view :View ?,pageCount:Int) {
        hideLoadingDialog()
    }

    override fun onRewardTimeOut() {
        hideLoadingDialog()
    }
    

    override fun popupLoginDialog(){
        val dialog = RewardGuideLoginDialog(this, object : RewardGuideLoginDialog.Listener {
            override fun onBtnOpen() {
                tryCatch {
                    val intent = Intent()
                    intent.setClassName("com.qihoo360.mobilesafe", "com.qihoo360.mobilesafe.accounts.a.LoginRegisterActivity")
                    startActivity(intent)
                }
            }

        })
        dialog.show()
    }

    override fun popupAuthGuideDialog(desc: String, authCode: Int) {
        val dialog = RewardAuthGuideDialog(this,desc,authCode,object:RewardAuthGuideDialog.Listener {
            override fun onBtnOk(authCode: Int) {
                AuthGuideServiceHelper.setAuthStatus(this@RaffleBaseActivity,authCode,true)
                AuthGuideServiceHelper.startAuthGuide(this@RaffleBaseActivity,authCode)
            }

            override fun onBtnCancel() {
            }
        })
        dialog.show()
    }

    override fun refreshTryResultStatus(rewardInfo: RewardUtils.RewardInfo?) {
    }

    override fun onDestroy() {
        super.onDestroy()
        tryCatch {
            mPresenter.onDestroy()
        }
    }

}


/**
 *1、无广告
 * 2、超时
 *  3、无网络
 */
enum class Status{
   EMPTY,TIMEOUT,NET
}