package com.qihoo360.mobilesafe.reward.ui.page.dialog

import android.app.Activity
import android.content.Context
import android.content.Intent
import android.os.Bundle
import android.view.View
import com.qihoo360.i.Factory
import com.qihoo360.i.IPluginManager
import com.qihoo360.mobilesafe.extension.setVisible
import com.qihoo360.mobilesafe.extension.tryCatch
import com.qihoo360.mobilesafe.reward.R
import com.qihoo360.mobilesafe.reward.data.RewardUtils
import com.qihoo360.mobilesafe.reward.ui.page.RaffleBaseActivity
import com.qihoo360.mobilesafe.ui.common.dialog.CommonBaseDialog
import kotlinx.android.synthetic.main.dialog_reward_result.*

open class RewardResultDialog(private val mContext: Activity,private var mRewardInfo: RewardUtils.RewardInfo?,
                         private var mSucceed: Boolean,private var mShareCanTryAgain :Boolean) :
        CommonBaseDialog(mContext, R.style.common_dialog), View.OnClickListener{

    private val mClickInterval :Long = 500

    private var mLastClick :Long = 0

    private val isClickTooFast : Boolean
    get()  {
        val now = System.currentTimeMillis()
        if(Math.abs(now - mLastClick) < mClickInterval){
            return true
        }
        mLastClick = now
        return false
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        if(setLayoutId() != -1) {
            setContentView(setLayoutId())
        }
        setCanceledOnTouchOutside(false)
        init()
        mClose?.setOnClickListener(this)
        mButtonCheckBalance?.setOnClickListener(this)
        mButtonShare?.setOnClickListener(this)
        mButtonBack?.setOnClickListener(this)
    }

    open  fun  setLayoutId() :Int {
        return R.layout.dialog_reward_result
    }

   open fun init(){
        if(!mSucceed) {
            mBonusFail?.setVisible(true)
            if(mShareCanTryAgain && mRewardInfo?.rewardBasicInfo != null && mRewardInfo?.tryResponse != null){
                mResultTipFriendShare?.setVisible(true)

                mButtonBack?.setVisible(false)
            }else{
                mFailedTipNone?.setVisible(true)
                mButtonShare?.setVisible(false)
            }
        }else {
            if (mRewardInfo?.rewardBasicInfo != null && mRewardInfo?.commitResponse != null) {
                val amount = mRewardInfo!!.commitResponse.amount
                if (amount > 0) {
                    mBonusOk?.setVisible(true)
                    mResultTipOk?.setVisible(true)
                    val share = RewardUtils.getSharedInfo(mContext)
                    if (share == 1 || !mShareCanTryAgain) {
                        mResultTipFriend?.setVisible(true)
                    } else {
                        mResultTipFriendShare?.setVisible(true)
                    }

                    val d = amount / 100.0
                    mBonusNum?.text = d.toString()
                    mButtonBack.setVisible(false)
                    val bonus = mRewardInfo!!.commitResponse.bonus
                    if (bonus in 1..(amount - 1)) {
                        val bonusExtra = amount - bonus
                        mBonusOkExtra?.setVisible(true)
                        val bonusExtraString = mContext.getString(R.string.apullsdk_hongbao_bonus_money,
                                (bonusExtra / 100.0).toString(), (bonus / 100.0).toString())
                        mBonusNumExtra?.text = bonusExtraString
                    }
                } else {
                    mBonusFail?.setVisible(true)
                    mResultTipNone?.setVisible(true)
                    mButtonShare?.setVisible(false)
                }
            }else{
                dismiss()
            }
        }
    }

    override fun onClick(v: View?) {
        if(isClickTooFast){
            return
        }
        when(v?.id){
            R.id.mClose ->{

                if(mContext is RaffleBaseActivity){
                    mContext.onBackPressedDownDialog(mRewardInfo)
                }
                dismiss()
            }

            R.id.mButtonBack ->{

                if(mContext is RaffleBaseActivity){
                    mContext.onBackPressedDownDialog(mRewardInfo)
                }
                dismiss()
            }

            R.id.mButtonCheckBalance ->{
                Factory.startActivity(context, Intent(), "wallet", "com.qihoo360.mobilesafe.wallet.MainActivity",
                        IPluginManager.PROCESS_AUTO)
            }

            R.id.mButtonShare ->{

                RewardUtils.startShareApp(mContext, mRewardInfo)
                RewardUtils.setSharedInfo(mContext, 1)

                if(mContext is RaffleBaseActivity){
                    mContext.onBackPressedDownDialog(mRewardInfo)
                }
                dismiss()
            }
            else ->{

            }
        }
    }


    fun updateRewardInfo(rewardInfo: RewardUtils.RewardInfo?,succeed: Boolean,shareCanTryAgain:Boolean){
        mSucceed= succeed
        mShareCanTryAgain = shareCanTryAgain
        mRewardInfo = rewardInfo
        init()
    }
}